package com.zjsgfa.project.zjsgfa.service;

import java.util.List;
import com.zjsgfa.project.zjsgfa.domain.SjZtgjsj;

/**
 * 设计-钻头关键数据分析Service接口
 * 
 * @author
 * @date 2025-07-22
 */
public interface ISjZtgjsjService 
{
    /**
     * 查询设计-钻头关键数据分析
     * 
     * @param id 设计-钻头关键数据分析主键
     * @return 设计-钻头关键数据分析
     */
    public SjZtgjsj selectSjZtgjsjById(Long id);

    /**
     * 查询设计-钻头关键数据分析列表
     * 
     * @param sjZtgjsj 设计-钻头关键数据分析
     * @return 设计-钻头关键数据分析集合
     */
    public List<SjZtgjsj> selectSjZtgjsjList(SjZtgjsj sjZtgjsj);

    /**
     * 新增设计-钻头关键数据分析
     * 
     * @param sjZtgjsj 设计-钻头关键数据分析
     * @return 结果
     */
    public int insertSjZtgjsj(SjZtgjsj sjZtgjsj);

    /**
     * 修改设计-钻头关键数据分析
     * 
     * @param sjZtgjsj 设计-钻头关键数据分析
     * @return 结果
     */
    public int updateSjZtgjsj(SjZtgjsj sjZtgjsj);

    /**
     * 批量删除设计-钻头关键数据分析
     * 
     * @param ids 需要删除的设计-钻头关键数据分析主键集合
     * @return 结果
     */
    public int deleteSjZtgjsjByIds(Long[] ids);

    /**
     * 删除设计-钻头关键数据分析信息
     * 
     * @param id 设计-钻头关键数据分析主键
     * @return 结果
     */
    public int deleteSjZtgjsjById(Long id);
}
